@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 12:16, 18/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -12,3 +12,7 @@ from . import SMA
 from . import TPO
 from . import VCS
 from . import WHO
+from . import BMO
+from . import SOS
+from . import SOA
+from . import TSA
