@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 17:44, 18/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -10,3 +10,7 @@ from . import GBO
 from . import HC
 from . import PSS
 from . import SCA
+from . import CEM
+from . import INFO
+from . import RUN
+from . import CircleSA
