@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 21:19, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -10,11 +10,7 @@ from mealpy.optimizer import Optimizer
 
 class BaseEFO(Optimizer):
     """
-    My changed version of: Electromagnetic Field Optimization (EFO)
-
-    Notes
-    ~~~~~
-    + Changed the flow of original algorithm and using global best solution in equation.
+    The developed version: Electromagnetic Field Optimization (EFO)
 
     Hyper-parameters should fine-tune in approximate range to get faster convergence toward the global optimum:
         + r_rate (float): [0.1, 0.6], default = 0.3, like mutation parameter in GA but for one variable
@@ -43,15 +39,14 @@ class BaseEFO(Optimizer):
     >>> ps_rate = 0.85
     >>> p_field = 0.1
     >>> n_field = 0.45
-    >>> model = BaseEFO(problem_dict1, epoch, pop_size, r_rate, ps_rate, p_field, n_field)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = BaseEFO(epoch, pop_size, r_rate, ps_rate, p_field, n_field)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, r_rate=0.3, ps_rate=0.85, p_field=0.1, n_field=0.45, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, r_rate=0.3, ps_rate=0.85, p_field=0.1, n_field=0.45, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             r_rate (float): default = 0.3     Like mutation parameter in GA but for one variable
@@ -59,13 +54,15 @@ class BaseEFO(Optimizer):
             p_field (float): default = 0.1     portion of population, positive field
             n_field (float): default = 0.45    portion of population, negative field
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.r_rate = self.validator.check_float("r_rate", r_rate, (0, 1.0))
         self.ps_rate = self.validator.check_float("ps_rate", ps_rate, (0, 1.0))
         self.p_field = self.validator.check_float("p_field", p_field, (0, 1.0))
         self.n_field = self.validator.check_float("n_field", n_field, (0, 1.0))
+        self.set_parameters(["epoch", "pop_size", "r_rate", "ps_rate", "p_field", "n_field"])
+
         self.phi = (1 + np.sqrt(5)) / 2  # golden ratio
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = True
@@ -144,8 +141,8 @@ class OriginalEFO(BaseEFO):
     >>> ps_rate = 0.85
     >>> p_field = 0.1
     >>> n_field = 0.45
-    >>> model = OriginalEFO(problem_dict1, epoch, pop_size, r_rate, ps_rate, p_field, n_field)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalEFO(epoch, pop_size, r_rate, ps_rate, p_field, n_field)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -155,10 +152,9 @@ class OriginalEFO(BaseEFO):
     Swarm and Evolutionary Computation, 26, pp.8-22.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, r_rate=0.3, ps_rate=0.85, p_field=0.1, n_field=0.45, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, r_rate=0.3, ps_rate=0.85, p_field=0.1, n_field=0.45, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             r_rate (float): default = 0.3     Like mutation parameter in GA but for one variable
@@ -166,9 +162,8 @@ class OriginalEFO(BaseEFO):
             p_field (float): default = 0.1     portion of population, positive field
             n_field (float): default = 0.45    portion of population, negative field
         """
-        super().__init__(problem, epoch, pop_size, r_rate, ps_rate, p_field, n_field, **kwargs)
-        self.nfe_per_epoch = self.pop_size
-        self.sort_flag = True
+        super().__init__(epoch, pop_size, r_rate, ps_rate, p_field, n_field, **kwargs)
+        self.support_parallel_modes = False
 
     def amend_position(self, position=None, lb=None, ub=None):
         """
@@ -185,9 +180,7 @@ class OriginalEFO(BaseEFO):
         """
         return np.where(np.logical_and(lb <= position, position <= ub), position, np.random.uniform(lb, ub))
 
-    def after_initialization(self):
-        self.pop, self.g_best = self.get_global_best_solution(self.pop)
-
+    def initialization(self):
         # %random vectors (this is to increase the calculation speed instead of determining the random values in each
         # iteration we allocate them in the beginning before algorithm start
         self.r_index1 = np.random.randint(0, int(self.pop_size * self.p_field), (self.problem.n_dims, self.epoch))
@@ -207,6 +200,9 @@ class OriginalEFO(BaseEFO):
         self.RI = 0
         # index of the electromagnet (variable) which is going to be initialized by random number
 
+        if self.pop is None:
+            self.pop = self.create_population(self.pop_size)
+
     def evolve(self, epoch):
         """
         The main operations (equations) of algorithm. Inherit from Optimizer class
