@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 07:03, 18/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -9,7 +9,7 @@ from copy import deepcopy
 from mealpy.optimizer import Optimizer
 
 
-class BaseHGSO(Optimizer):
+class OriginalHGSO(Optimizer):
     """
     The original version of: Henry Gas Solubility Optimization (HGSO)
 
@@ -22,7 +22,7 @@ class BaseHGSO(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.physics_based.HGSO import BaseHGSO
+    >>> from mealpy.physics_based.HGSO import OriginalHGSO
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -37,8 +37,8 @@ class BaseHGSO(Optimizer):
     >>> epoch = 1000
     >>> pop_size = 50
     >>> n_clusters = 3
-    >>> model = BaseHGSO(problem_dict1, epoch, pop_size, n_clusters)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalHGSO(epoch, pop_size, n_clusters)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -47,18 +47,19 @@ class BaseHGSO(Optimizer):
     optimization: A novel physics-based algorithm. Future Generation Computer Systems, 101, pp.646-667.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, n_clusters=2, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, n_clusters=2, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             n_clusters (int): number of clusters, default = 2
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.n_clusters = self.validator.check_int("n_clusters", n_clusters, [2, int(self.pop_size/5)])
+        self.set_parameters(["epoch", "pop_size", "n_clusters"])
+
         self.n_elements = int(self.pop_size / self.n_clusters)
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = False
@@ -67,26 +68,22 @@ class BaseHGSO(Optimizer):
         self.beta = 1.0
         self.alpha = 1
         self.epxilon = 0.05
-
         self.l1 = 5E-2
         self.l2 = 100.0
         self.l3 = 1E-2
+
+    def initialize_variables(self):
         self.H_j = self.l1 * np.random.uniform()
         self.P_ij = self.l2 * np.random.uniform()
         self.C_j = self.l3 * np.random.uniform()
         self.pop_group, self.p_best = None, None
 
-    def after_initialization(self):
-        _, self.g_best = self.get_global_best_solution(self.pop)
-        self.pop_group = self.create_group__(self.pop)
+    def initialization(self):
+        if self.pop is None:
+            self.pop = self.create_population(self.pop_size)
+        self.pop_group = self.create_pop_group(self.pop, self.n_clusters, self.n_elements)
         self.p_best = self.get_best_solution_in_team__(self.pop_group)  # multiple element
 
-    def create_group__(self, pop):
-        pop_group = []
-        for idx in range(0, self.n_clusters):
-            pop_group.append(pop[idx * self.n_elements:(idx + 1) * self.n_elements])
-        return pop_group
-
     def flatten_group__(self, group):
         pop = []
         for idx in range(0, self.n_clusters):
@@ -155,6 +152,6 @@ class BaseHGSO(Optimizer):
         nfe_epoch += N_w
         for idx, id_selected in enumerate(pop_idx):
             self.pop[id_selected] = deepcopy(pop_new[idx])
-        self.pop_group = self.create_group__(self.pop)
+        self.pop_group = self.create_pop_group(self.pop, self.n_clusters, self.n_elements)
         self.p_best = self.get_best_solution_in_team__(self.pop_group)
         self.nfe_per_epoch = nfe_epoch
