@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 21:18, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -9,7 +9,7 @@ from copy import deepcopy
 from mealpy.optimizer import Optimizer
 
 
-class BaseTWO(Optimizer):
+class OriginalTWO(Optimizer):
     """
     The original version of: Tug of War Optimization (TWO)
 
@@ -19,7 +19,7 @@ class BaseTWO(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.physics_based.TWO import BaseTWO
+    >>> from mealpy.physics_based.TWO import OriginalTWO
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -33,8 +33,8 @@ class BaseTWO(Optimizer):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> model = BaseTWO(problem_dict1, epoch, pop_size)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalTWO(epoch, pop_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -47,16 +47,16 @@ class BaseTWO(Optimizer):
     ID_TAR = 1
     ID_WEIGHT = 2
 
-    def __init__(self, problem, epoch=10000, pop_size=100, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
+        self.set_parameters(["epoch", "pop_size"])
 
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = False
@@ -66,8 +66,9 @@ class BaseTWO(Optimizer):
         self.alpha = 0.99
         self.beta = 0.1
 
-    def after_initialization(self):
-        _, self.g_best = self.get_global_best_solution(self.pop)
+    def initialization(self):
+        if self.pop is None:
+            self.pop = self.create_population(self.pop_size)
         self.pop = self.update_weight__(self.pop)
 
     def create_solution(self, lb=None, ub=None, pos=None):
@@ -140,13 +141,9 @@ class BaseTWO(Optimizer):
         self.pop = self.update_weight__(self.pop)
 
 
-class OppoTWO(BaseTWO):
+class OppoTWO(OriginalTWO):
     """
-    The opossition-based learning version of: Tug of War Optimization (OTWO)
-
-    Notes
-    ~~~~~
-    + Applied the idea of Opposition-based learning technique
+    The opossition-based learning version: Tug of War Optimization (OTWO)
 
     Examples
     ~~~~~~~~
@@ -165,23 +162,22 @@ class OppoTWO(BaseTWO):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> model = OppoTWO(problem_dict1, epoch, pop_size)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OppoTWO(epoch, pop_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
         """
-        super().__init__(problem, epoch, pop_size, **kwargs)
-        self.nfe_per_epoch = self.pop_size
-        self.sort_flag = False
+        super().__init__(epoch, pop_size, **kwargs)
 
-    def after_initialization(self):
+    def initialization(self):
+        if self.pop is None:
+            self.pop = self.create_population(self.pop_size)
         list_idx = np.random.choice(range(0, self.pop_size), int(self.pop_size/2), replace=False)
         pop_temp = [self.pop[list_idx[idx]] for idx in range(0, int(self.pop_size/2))]
         pop_oppo = []
@@ -194,7 +190,6 @@ class OppoTWO(BaseTWO):
         pop_oppo = self.update_target_wrapper_population(pop_oppo)
         self.pop = pop_temp + pop_oppo
         self.pop = self.update_weight__(self.pop)
-        _, self.g_best = self.get_global_best_solution(self.pop)
 
     def evolve(self, epoch):
         """
@@ -253,13 +248,9 @@ class OppoTWO(BaseTWO):
         self.nfe_per_epoch = nfe_epoch
 
 
-class LevyTWO(BaseTWO):
+class LevyTWO(OriginalTWO):
     """
-    The Levy-flight version of: Tug of War Optimization (LTWO)
-
-    Notes
-    ~~~~~
-    + Applied the idea of Levy-flight technique
+    The Levy-flight version of: Tug of War Optimization (LevyTWO)
 
     Examples
     ~~~~~~~~
@@ -278,21 +269,18 @@ class LevyTWO(BaseTWO):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> model = LevyTWO(problem_dict1, epoch, pop_size)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = LevyTWO(epoch, pop_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
         """
-        super().__init__(problem, epoch, pop_size, **kwargs)
-        self.nfe_per_epoch = self.pop_size
-        self.sort_flag = False
+        super().__init__(epoch, pop_size, **kwargs)
 
     def evolve(self, epoch):
         """
@@ -378,12 +366,8 @@ class EnhancedTWO(OppoTWO, LevyTWO):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> r_rate = 0.3
-    >>> ps_rate = 0.85
-    >>> p_field = 0.1
-    >>> n_field = 0.45
-    >>> model = EnhancedTWO(problem_dict1, epoch, pop_size, r_rate, ps_rate, p_field, n_field)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = EnhancedTWO(epoch, pop_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -392,18 +376,17 @@ class EnhancedTWO(OppoTWO, LevyTWO):
     extreme learning machine and enhanced tug of war optimization. Procedia Computer Science, 170, pp.362-369.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
         """
-        super().__init__(problem, epoch, pop_size, **kwargs)
-        self.nfe_per_epoch = self.pop_size
-        self.sort_flag = False
+        super().__init__(epoch, pop_size, **kwargs)
 
-    def after_initialization(self):
+    def initialization(self):
+        if self.pop is None:
+            self.pop = self.create_population(self.pop_size)
         pop_oppo = deepcopy(self.pop)
         for i in range(self.pop_size):
             pos_opposite = self.problem.ub + self.problem.lb - self.pop[i][self.ID_POS]
@@ -414,7 +397,6 @@ class EnhancedTWO(OppoTWO, LevyTWO):
         pop_oppo = self.update_target_wrapper_population(pop_oppo)
         self.pop = self.get_sorted_strim_population(self.pop + pop_oppo, self.pop_size)
         self.pop = self.update_weight__(self.pop)
-        self.g_best = deepcopy(self.pop[0])
 
     def evolve(self, epoch):
         """
