@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 12:00, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -41,9 +41,10 @@ class OriginalBA(Optimizer):
     >>> pop_size = 50
     >>> loudness = 0.8
     >>> pulse_rate = 0.95
-    >>> pulse_frequency = [0, 10]
-    >>> model = OriginalBA(problem_dict1, epoch, pop_size, loudness, pulse_rate, pulse_frequency)
-    >>> best_position, best_fitness = model.solve()
+    >>> pf_min = 0.
+    >>> pf_max = 10.
+    >>> model = OriginalBA(epoch, pop_size, loudness, pulse_rate, pf_min, pf_max)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -55,22 +56,25 @@ class OriginalBA(Optimizer):
     ID_VEC = 2  # Velocity
     ID_PFRE = 3  # Pulse Frequency
 
-    def __init__(self, problem, epoch=10000, pop_size=100, loudness=0.8, pulse_rate=0.95, pulse_frequency=(0, 10), **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, loudness=0.8, pulse_rate=0.95, pf_min=0., pf_max=10., **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             loudness (float): (A_min, A_max): loudness, default = 0.8
             pulse_rate (float): (r_min, r_max): pulse rate / emission rate, default = 0.95
-            pulse_frequency (list, tuple): (pf_min, pf_max): pulse frequency, default = (0, 10)
+            pf_min (float): pulse frequency min, default = 0
+            pf_max (float): pulse frequency max, default = 10
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.loudness = self.validator.check_float("loudness", loudness, (0, 1.0))
         self.pulse_rate = self.validator.check_float("pulse_rate", pulse_rate, (0, 1.0))
-        self.pulse_frequency = self.validator.check_tuple_float("pulse_frequency (pf_min, pf_max)", pulse_frequency, ([0, 2], [2, 10]))
+        self.pf_min = self.validator.check_float("pf_min", pf_min, [0., 3.0])
+        self.pf_max = self.validator.check_float("pf_max", pf_max, [5., 20.])
+        self.set_parameters(["epoch", "pop_size", "loudness", "pulse_rate", "pf_min", "pf_max"])
+
         self.alpha = self.gamma = 0.9
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = False
@@ -87,7 +91,7 @@ class OriginalBA(Optimizer):
         position = self.amend_position(pos, lb, ub)
         target = self.get_target_wrapper(position)
         velocity = np.random.uniform(lb, ub)
-        pulse_frequency = self.pulse_frequency[0] + (self.pulse_frequency[1] - self.pulse_frequency[0]) * np.random.uniform()
+        pulse_frequency = self.pf_min + (self.pf_max - self.pf_min) * np.random.uniform()
         return [position, target, velocity, pulse_frequency]
 
     def evolve(self, epoch):
@@ -118,23 +122,26 @@ class OriginalBA(Optimizer):
                 self.pop[idx] = deepcopy(pop_new[idx])
 
 
-class BaseBA(Optimizer):
+class AdaptiveBA(Optimizer):
     """
-    The original version of: Bat-inspired Algorithm (BA)
+    The original version of: Adaptive Bat-inspired Algorithm (BA)
 
     Notes
     ~~~~~
     + The value of A and r are changing after each iteration
 
     Hyper-parameters should fine-tune in approximate range to get faster convergence toward the global optimum:
-        + loudness (tuple, list): (A_min, A_max) -> ([0.5, 1.5], [1.0, 3.0]): loudness, default = (1.0, 2.0)
-        + pulse_rate (tuple, list): (r_min, r_max) -> ([0.1, 0.5], [0.5, 0.95]), pulse rate / emission rate, default = (0.15, 0.85)
-        + pulse_frequency (tuple, list): (pf_min, pf_max) -> ([0, 3], [5, 20]), pulse frequency, default = (0, 10)
+        + loudness_min (float): A_min - loudness, default=1.0
+        + loudness_max (float): A_max - loudness, default=2.0
+        + pr_min (float): pulse rate / emission rate min, default = 0.15
+        + pr_max (float): pulse rate / emission rate max, default = 0.85
+        + pf_min (float): pulse frequency min, default = 0
+        + pf_max (float): pulse frequency max, default = 10
 
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.swarm_based.BA import BaseBA
+    >>> from mealpy.swarm_based.BA import AdaptiveBA
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -148,11 +155,14 @@ class BaseBA(Optimizer):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> loudness = [1.0, 2.0]
-    >>> pulse_rate = [0.15, 0.85]
-    >>> pulse_frequency = [0, 10]
-    >>> model = BaseBA(problem_dict1, epoch, pop_size, loudness, pulse_rate, pulse_frequency)
-    >>> best_position, best_fitness = model.solve()
+    >>> loudness_min = 1.0 
+    >>> loudness_max = 2.0 
+    >>> pr_min = 0.15
+    >>> pr_max = 0.85
+    >>> pf_min = 0.
+    >>> pf_max = 10.
+    >>> model = AdaptiveBA(epoch, pop_size, loudness_min, loudness_max, pr_min, pr_max, pf_min, pf_max)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -166,27 +176,32 @@ class BaseBA(Optimizer):
     ID_PRAT = 4  # Pulse Rate
     ID_PFRE = 5  # Pulse Frequency
 
-    def __init__(self, problem, epoch=10000, pop_size=100, loudness=(1.0, 2.0),
-                 pulse_rate=(0.15, 0.85), pulse_frequency=(0, 10), **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, loudness_min=1.0, loudness_max=2.0, pr_min=0.15, pr_max=0.85, pf_min=0., pf_max=10., **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
-            loudness (tuple, list): (A_min, A_max): loudness, default = (1.0, 2.0)
-            pulse_rate (tuple, list): (r_min, r_max): pulse rate / emission rate, default = (0.15, 0.85)
-            pulse_frequency (tuple, list): (pf_min, pf_max): pulse frequency, default = (0, 10)
+            loudness_min (float): A_min - loudness, default=1.0
+            loudness_max (float): A_max - loudness, default=2.0
+            pr_min (float): pulse rate / emission rate min, default = 0.15
+            pr_max (float): pulse rate / emission rate max, default = 0.85
+            pf_min (float): pulse frequency min, default = 0
+            pf_max (float): pulse frequency max, default = 10
         """
-        super().__init__(problem, kwargs)
-        self.nfe_per_epoch = pop_size
-        self.sort_flag = False
-
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
-        self.loudness = self.validator.check_tuple_float("loudness (A_min, A_max)", loudness, ([0.5, 1.0], [1.0, 3.0]))
-        self.pulse_rate = self.validator.check_tuple_float("pulse_rate (r_min, r_max)", pulse_rate, ((0, 1.0), (0, 1.0)))
-        self.pulse_frequency = self.validator.check_tuple_float("pulse_frequency (pf_min, pf_max)", pulse_frequency, ([0, 2], [2, 10]))
+        self.loudness_min = self.validator.check_float("loudness_min", loudness_min, [0.5, 1.5])
+        self.loudness_max = self.validator.check_float("loudness_max", loudness_max, [1.5, 3.0])
+        self.pr_min = self.validator.check_float("pr_min", pr_min, (0, 1.0))
+        self.pr_max = self.validator.check_float("pr_max", pr_max, (0, 1.0))
+        self.pf_min = self.validator.check_float("pf_min", pf_min, [0, 2])
+        self.pf_max = self.validator.check_float("pf_max", pf_max, [2, 10])
         self.alpha = self.gamma = 0.9
+        self.set_parameters(["epoch", "pop_size", "loudness_min", "loudness_max", "pr_min", "pr_max", "pf_min", "pf_max"])
+
+        self.nfe_per_epoch = self.pop_size
+        self.sort_flag = False
 
     def create_solution(self, lb=None, ub=None, pos=None):
         """
@@ -200,9 +215,9 @@ class BaseBA(Optimizer):
         position = self.amend_position(pos, lb, ub)
         target = self.get_target_wrapper(position)
         velocity = np.random.uniform(lb, ub)
-        loudness = np.random.uniform(self.loudness[0], self.loudness[1])
-        pulse_rate = np.random.uniform(self.pulse_rate[0], self.pulse_rate[1])
-        pulse_frequency = self.pulse_frequency[0] + (self.pulse_frequency[1] - self.pulse_frequency[0]) * np.random.uniform()
+        loudness = np.random.uniform(self.loudness_min, self.loudness_max)
+        pulse_rate = np.random.uniform(self.pr_min, self.pr_max)
+        pulse_frequency = self.pf_min + (self.pf_max - self.pf_min) * np.random.uniform()
         return [position, target, velocity, loudness, pulse_rate, pulse_frequency]
 
     def evolve(self, epoch):
@@ -239,15 +254,15 @@ class BaseBA(Optimizer):
 
 class ModifiedBA(Optimizer):
     """
-    My modified version of: Bat-inspired Algorithm (MBA)
+    The original version of: Modified Bat-inspired Algorithm (MBA)
 
     Notes
     ~~~~~
-    + Removes A (loudness) parameter
-    + Changed processes
-        + 1st: We proceed exploration phase (using frequency)
-        + 2nd: If new position has better fitness we replace the old position
-        + 3rd: Otherwise, we proceed exploitation phase (using finding around the best position so far)
+    + A (loudness) parameter is removed
+    + Flow is changed:
+        + 1st: the exploration phase is proceed (using frequency)
+        + 2nd: If new position has better fitness, replace the old position
+        + 3rd: Otherwise, proceed exploitation phase (using finding around the best position so far)
 
     Hyper-parameters should fine-tune in approximate range to get faster convergence toward the global optimum:
         + pulse_rate (float): [0.7, 1.0], pulse rate / emission rate, default = 0.95
@@ -271,31 +286,27 @@ class ModifiedBA(Optimizer):
     >>> epoch = 1000
     >>> pop_size = 50
     >>> pulse_rate = 0.95
-    >>> pulse_frequency = [0, 10]
-    >>> model = ModifiedBA(problem_dict1, epoch, pop_size, pulse_rate, pulse_frequency)
-    >>> best_position, best_fitness = model.solve()
+    >>> pf_min = 0.
+    >>> pf_max = 10.
+    >>> model = ModifiedBA(epoch, pop_size, pulse_rate, pf_min, pf_max)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, pulse_rate=0.95, pulse_frequency=(0, 10), **kwargs):
-        """
-        Args:
-            problem (dict): The problem dictionary
-            epoch (int): maximum number of iterations, default = 10000
-            pop_size (int): number of population size, default = 100
-            pulse_rate (float): pulse rate / emission rate, default = 0.95
-            pulse_frequency (tuple, list): (pf_min, pf_max): pulse frequency, default = (0, 10)
-        """
-        super().__init__(problem, kwargs)
-        self.nfe_per_epoch = pop_size
-        self.sort_flag = False
-
+    def __init__(self, epoch=10000, pop_size=100, pulse_rate=0.95, pf_min=0., pf_max=10., **kwargs):
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.pulse_rate = self.validator.check_float("pulse_rate", pulse_rate, (0, 1.0))
-        self.pulse_frequency = self.validator.check_tuple_float("pulse_frequency (pf_min, pf_max)", pulse_frequency, ([0, 2], [2, 10]))
+        self.pf_min = self.validator.check_float("pf_min", pf_min, [0, 2])
+        self.pf_max = self.validator.check_float("pf_max", pf_max, [2, 10])
         self.alpha = self.gamma = 0.9
+        self.set_parameters(["epoch", "pop_size", "pulse_rate", "pf_min", "pf_max"])
 
+        self.nfe_per_epoch = self.pop_size
+        self.sort_flag = False
+
+    def initialize_variables(self):
         self.dyn_list_velocity = np.zeros((self.pop_size, self.problem.n_dims))
 
     def evolve(self, epoch):
@@ -308,7 +319,7 @@ class ModifiedBA(Optimizer):
         nfe_epoch = 0
         pop_new = []
         for idx in range(0, self.pop_size):
-            pf = self.pulse_frequency[0] + (self.pulse_frequency[1] - self.pulse_frequency[0]) * np.random.uniform()  # Eq. 2
+            pf = self.pf_min + (self.pf_max - self.pf_min) * np.random.uniform()  # Eq. 2
             self.dyn_list_velocity[idx] = np.random.uniform() * self.dyn_list_velocity[idx] + \
                                           (self.g_best[self.ID_POS] - self.pop[idx][self.ID_POS]) * pf  # Eq. 3
             x = self.pop[idx][self.ID_POS] + self.dyn_list_velocity[idx]  # Eq. 4
