@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 11:59, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -9,12 +9,12 @@ from copy import deepcopy
 from mealpy.optimizer import Optimizer
 
 
-class BaseBSA(Optimizer):
+class OriginalBSA(Optimizer):
     """
     The original version of: Bird Swarm Algorithm (BSA)
 
     Links:
-        1. http://doi.org/10.1080/0952813X.2015.1042530
+        1. https://doi.org/10.1080/0952813X.2015.1042530
         2. https://www.mathworks.com/matlabcentral/fileexchange/51256-bird-swarm-algorithm-bsa
 
     Hyper-parameters should fine-tune in approximate range to get faster convergence toward the global optimum:
@@ -27,7 +27,7 @@ class BaseBSA(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.swarm_based.BSA import BaseBSA
+    >>> from mealpy.swarm_based.BSA import OriginalBSA
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -43,11 +43,13 @@ class BaseBSA(Optimizer):
     >>> pop_size = 50
     >>> ff = 10
     >>> pff = 0.8
-    >>> c_couples = [1.5, 1.5]
-    >>> a_couples = [1.0, 1.0]
+    >>> c1 = 1.5
+    >>> c2 = 1.5
+    >>> a1 = 1.0
+    >>> a2 = 1.0
     >>> fl = 0.5
-    >>> model = BaseBSA(problem_dict1, epoch, pop_size, ff, pff, c_couples, a_couples, fl)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalBSA(epoch, pop_size, ff, pff, c1, c2, a1, a2, fl)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -62,27 +64,30 @@ class BaseBSA(Optimizer):
     ID_LBP = 2  # local best position
     ID_LBF = 3  # local best fitness
 
-    def __init__(self, problem, epoch=10000, pop_size=100,
-                 ff=10, pff=0.8, c_couples=(1.5, 1.5), a_couples=(1.0, 1.0), fl=0.5, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, ff=10, pff=0.8, c1=1.5, c2=1.5, a1=1.0, a2=1.0, fl=0.5, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             ff (int): flight frequency - default = 10
             pff (float): the probability of foraging for food - default = 0.8
-            c_couples (list, tuple): [c1, c2]: Cognitive accelerated coefficient, Social accelerated coefficient same as PSO
-            a_couples (list, tuple): [a1, a2]: The indirect and direct effect on the birds' vigilance behaviours.
-            fl (float): The followed coefficient- default = 0.5
+            c1 (float): Cognitive accelerated coefficient same as PSO
+            c2 (float): Social accelerated coefficient same as PSO
+            a1 (float): The indirect effect on the birds' vigilance behaviours.
+            a2 (float): The direct effect on the birds' vigilance behaviours.
+            fl (float): The followed coefficient - default = 0.5
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.ff = self.validator.check_int("ff", ff, [2, int(self.pop_size/2)])
         self.pff = self.validator.check_float("pff", pff, (0, 1.0))
-        self.c_couples = self.validator.check_tuple_float("c_couples (cognitive, social)", c_couples, ((0, 3.0), (0, 3.0)))
-        self.a_couples = self.validator.check_tuple_float("a_couples (indirect, direct)", a_couples, ((0, 3.0), (0, 3.0)))
+        self.c1 = self.validator.check_float("c1", c1, (0, 5.0))
+        self.c2 = self.validator.check_float("c2", c2, (0, 5.0))
+        self.a1 = self.validator.check_float("a1", a1, (0, 5.0))
+        self.a2 = self.validator.check_float("a2", a2, (0, 5.0))
         self.fl = self.validator.check_float("fl", fl, (0, 1.0))
+        self.set_parameters(["epoch", "pop_size", "ff", "pff", "c1", "c2", "a1", "a2", "fl"])
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = False
 
@@ -120,14 +125,14 @@ class BaseBSA(Optimizer):
                 agent = deepcopy(self.pop[i])
                 prob = np.random.uniform() * 0.2 + self.pff  # The probability of foraging for food
                 if np.random.uniform() < prob:  # Birds forage for food. Eq. 1
-                    x_new = self.pop[i][self.ID_POS] + self.c_couples[0] * \
+                    x_new = self.pop[i][self.ID_POS] + self.c1 * \
                             np.random.uniform() * (self.pop[i][self.ID_LBP] - self.pop[i][self.ID_POS]) + \
-                            self.c_couples[1] * np.random.uniform() * (self.g_best[self.ID_POS] - self.pop[i][self.ID_POS])
+                            self.c2 * np.random.uniform() * (self.g_best[self.ID_POS] - self.pop[i][self.ID_POS])
                 else:  # Birds keep vigilance. Eq. 2
-                    A1 = self.a_couples[0] * np.exp(-self.pop_size * self.pop[i][self.ID_LBF][self.ID_FIT] / (self.EPSILON + fit_sum))
+                    A1 = self.a1 * np.exp(-self.pop_size * self.pop[i][self.ID_LBF][self.ID_FIT] / (self.EPSILON + fit_sum))
                     k = np.random.choice(list(set(range(0, self.pop_size)) - {i}))
                     t1 = (fit_list[i] - fit_list[k]) / (abs(fit_list[i] - fit_list[k]) + self.EPSILON)
-                    A2 = self.a_couples[1] * np.exp(t1 * self.pop_size * fit_list[k] / (fit_sum + self.EPSILON))
+                    A2 = self.a2 * np.exp(t1 * self.pop_size * fit_list[k] / (fit_sum + self.EPSILON))
                     x_new = self.pop[i][self.ID_POS] + A1 * np.random.uniform(0, 1) * (pos_mean - self.pop[i][self.ID_POS]) + \
                             A2 * np.random.uniform(-1, 1) * (self.g_best[self.ID_POS] - self.pop[i][self.ID_POS])
                 pos_new = self.amend_position(x_new, self.problem.lb, self.problem.ub)
