@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 14:52, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -8,7 +8,7 @@ import numpy as np
 from mealpy.optimizer import Optimizer
 
 
-class BaseMRFO(Optimizer):
+class OriginalMRFO(Optimizer):
     """
     The original version of: Manta Ray Foraging Optimization (MRFO)
 
@@ -21,7 +21,7 @@ class BaseMRFO(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.swarm_based.MRFO import BaseMRFO
+    >>> from mealpy.swarm_based.MRFO import OriginalMRFO
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -36,8 +36,8 @@ class BaseMRFO(Optimizer):
     >>> epoch = 1000
     >>> pop_size = 50
     >>> somersault_range = 2.0
-    >>> model = BaseMRFO(problem_dict1, epoch, pop_size, somersault_range)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalMRFO(epoch, pop_size, somersault_range)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -46,18 +46,18 @@ class BaseMRFO(Optimizer):
     optimizer for engineering applications. Engineering Applications of Artificial Intelligence, 87, p.103300.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, somersault_range=2.0, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, somersault_range=2.0, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             somersault_range (float): somersault factor that decides the somersault range of manta rays, default=2
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.somersault_range = self.validator.check_int("somersault_range", somersault_range, [1.0, 5.0])
+        self.set_parameters(["epoch", "pop_size", "somersault_range"])
         self.nfe_per_epoch = 2 * self.pop_size
         self.sort_flag = False
 
