@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 14:52, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -10,9 +10,9 @@ from copy import deepcopy
 from mealpy.optimizer import Optimizer
 
 
-class BaseMSA(Optimizer):
+class OriginalMSA(Optimizer):
     """
-    My changed version of: Moth Search Algorithm (MSA)
+    The original version: Moth Search Algorithm (MSA)
 
     Links:
         1. https://www.mathworks.com/matlabcentral/fileexchange/59010-moth-search-ms-algorithm
@@ -21,7 +21,7 @@ class BaseMSA(Optimizer):
     Notes
     ~~~~~
     + The matlab version of original paper is not good (especially convergence chart)
-    + I add Normal random number (Gaussian distribution) in each updating equation (Better performance)
+    + The random number (gaussian distribution) is added in each updating equation
 
     Hyper-parameters should fine-tune in approximate range to get faster convergence toward the global optimum:
         + n_best (int): [3, 10], how many of the best moths to keep from one generation to the next, default=5
@@ -31,7 +31,7 @@ class BaseMSA(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.swarm_based.MSA import BaseMSA
+    >>> from mealpy.swarm_based.MSA import OriginalMSA
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -48,8 +48,8 @@ class BaseMSA(Optimizer):
     >>> n_best = 5
     >>> partition = 0.5
     >>> max_step_size = 1.0
-    >>> model = BaseMSA(problem_dict1, epoch, pop_size, n_best, partition, max_step_size)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalMSA(epoch, pop_size, n_best, partition, max_step_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -58,23 +58,22 @@ class BaseMSA(Optimizer):
     global optimization problems. Memetic Computing, 10(2), pp.151-164.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, n_best=5, partition=0.5, max_step_size=1.0, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, n_best=5, partition=0.5, max_step_size=1.0, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             n_best (int): how many of the best moths to keep from one generation to the next, default=5
             partition (float): The proportional of first partition, default=0.5
             max_step_size (float): Max step size used in Levy-flight technique, default=1.0
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.n_best = self.validator.check_int("n_best", n_best, [2, int(self.pop_size/2)])
         self.partition = self.validator.check_float("partition", partition, (0, 1.0))
         self.max_step_size = self.validator.check_float("max_step_size", max_step_size, (0, 5.0))
-
+        self.set_parameters(["epoch", "pop_size", "n_best", "partition", "max_step_size"])
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = True
         # np1 in paper
