@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 14:51, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -9,7 +9,7 @@ from copy import deepcopy
 from mealpy.optimizer import Optimizer
 
 
-class BasePFA(Optimizer):
+class OriginalPFA(Optimizer):
     """
     The original version of: Pathfinder Algorithm (PFA)
 
@@ -19,7 +19,7 @@ class BasePFA(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.swarm_based.PFA import BasePFA
+    >>> from mealpy.swarm_based.PFA import OriginalPFA
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -33,8 +33,8 @@ class BasePFA(Optimizer):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> model = BasePFA(problem_dict1, epoch, pop_size)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalPFA(epoch, pop_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -43,16 +43,16 @@ class BasePFA(Optimizer):
     Applied soft computing, 78, pp.545-568.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
+        self.set_parameters(["epoch", "pop_size"])
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = True
 
@@ -65,6 +65,8 @@ class BasePFA(Optimizer):
         """
         alpha, beta = np.random.uniform(1, 2, 2)
         A = np.random.uniform(self.problem.lb, self.problem.ub) * np.exp(-2 * (epoch + 1) / self.epoch)
+        t = 1 - (epoch + 1) * 1.0 / self.epoch
+        space = self.problem.ub - self.problem.lb
 
         ## Update the position of pathfinder and check the bound
         pos_new = self.pop[0][self.ID_POS] + 2 * np.random.uniform() * (self.g_best[self.ID_POS] - self.pop[0][self.ID_POS]) + A
@@ -74,21 +76,22 @@ class BasePFA(Optimizer):
 
         ## Update positions of members, check the bound and calculate new fitness
         for idx in range(1, self.pop_size):
+            agent = deepcopy(self.pop[idx])
             pos_new = deepcopy(self.pop[idx][self.ID_POS]).astype(float)
             for k in range(1, self.pop_size):
                 dist = np.sqrt(np.sum((self.pop[k][self.ID_POS] - self.pop[idx][self.ID_POS]) ** 2)) / self.problem.n_dims
                 t2 = alpha * np.random.uniform() * (self.pop[k][self.ID_POS] - self.pop[idx][self.ID_POS])
                 ## First stabilize the distance
-                t3 = np.random.uniform() * (1 - (epoch + 1) * 1.0 / self.epoch) * (dist / (self.problem.ub - self.problem.lb))
+                t3 = np.random.uniform() * t * (dist / space)
                 pos_new += t2 + t3
             ## Second stabilize the population size
             t1 = beta * np.random.uniform() * (self.g_best[self.ID_POS] - self.pop[idx][self.ID_POS])
             pos_new = (pos_new + t1) / self.pop_size
             pos_new = self.amend_position(pos_new, self.problem.lb, self.problem.ub)
-            pop_new.append([pos_new, None])
+            agent[self.ID_POS] = pos_new
+            pop_new.append(agent)
             if self.mode not in self.AVAILABLE_MODES:
-                target = self.get_target_wrapper(pos_new)
-                self.pop[idx] = self.get_better_solution(self.pop[idx], [pos_new, target])
+                pop_new[-1][self.ID_TAR] = self.get_target_wrapper(pos_new)
         if self.mode in self.AVAILABLE_MODES:
             pop_new = self.update_target_wrapper_population(pop_new)
-            self.pop = self.greedy_selection_population(self.pop, pop_new)
+        self.pop = self.greedy_selection_population(self.pop, pop_new)
