@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 10:06, 17/03/2020 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -8,7 +8,7 @@ import numpy as np
 from mealpy.optimizer import Optimizer
 
 
-class BaseWOA(Optimizer):
+class OriginalWOA(Optimizer):
     """
     The original version of: Whale Optimization Algorithm (WOA)
 
@@ -18,7 +18,7 @@ class BaseWOA(Optimizer):
     Examples
     ~~~~~~~~
     >>> import numpy as np
-    >>> from mealpy.swarm_based.WOA import BaseWOA
+    >>> from mealpy.swarm_based.WOA import OriginalWOA
     >>>
     >>> def fitness_function(solution):
     >>>     return np.sum(solution**2)
@@ -32,8 +32,8 @@ class BaseWOA(Optimizer):
     >>>
     >>> epoch = 1000
     >>> pop_size = 50
-    >>> model = BaseWOA(problem_dict1, epoch, pop_size)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = OriginalWOA(epoch, pop_size)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -42,16 +42,17 @@ class BaseWOA(Optimizer):
     Advances in engineering software, 95, pp.51-67.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
+        self.set_parameters(["epoch", "pop_size"])
+
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = False
 
@@ -121,8 +122,8 @@ class HI_WOA(Optimizer):
     >>> epoch = 1000
     >>> pop_size = 50
     >>> feedback_max = 10
-    >>> model = HI_WOA(problem_dict1, epoch, pop_size, feedback_max)
-    >>> best_position, best_fitness = model.solve()
+    >>> model = HI_WOA(epoch, pop_size, feedback_max)
+    >>> best_position, best_fitness = model.solve(problem_dict1)
     >>> print(f"Solution: {best_position}, Fitness: {best_fitness}")
 
     References
@@ -131,23 +132,25 @@ class HI_WOA(Optimizer):
     In 2019 IEEE 15th International Conference on Control and Automation (ICCA) (pp. 362-367). IEEE.
     """
 
-    def __init__(self, problem, epoch=10000, pop_size=100, feedback_max=10, **kwargs):
+    def __init__(self, epoch=10000, pop_size=100, feedback_max=10, **kwargs):
         """
         Args:
-            problem (dict): The problem dictionary
             epoch (int): maximum number of iterations, default = 10000
             pop_size (int): number of population size, default = 100
             feedback_max (int): maximum iterations of each feedback, default = 10
         """
-        super().__init__(problem, kwargs)
+        super().__init__(**kwargs)
         self.epoch = self.validator.check_int("epoch", epoch, [1, 100000])
         self.pop_size = self.validator.check_int("pop_size", pop_size, [10, 10000])
         self.feedback_max = self.validator.check_int("feedback_max", feedback_max, [2, 2+int(self.epoch/2)])
         # The maximum of times g_best doesn't change -> need to change half of population
+        self.set_parameters(["epoch", "pop_size", "feedback_max"])
+
         self.nfe_per_epoch = self.pop_size
         self.sort_flag = True
-        self.n_changes = int(pop_size / 2)
-        ## Dynamic variable
+
+    def initialize_variables(self):
+        self.n_changes = int(self.pop_size / 2)
         self.dyn_feedback_count = 0
 
     def evolve(self, epoch):
