@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#!/usr/bin/env python
 # Created by "Thieu" at 17:12, 09/07/2021 ----------%
 #       Email: nguyenthieu2102@gmail.com            %
 #       Github: https://github.com/thieu1995        %
@@ -8,3 +8,6 @@ from . import history
 from . import problem
 from . import termination
 from . import visualize
+from . import validator
+from . import io
+from . import logger
