@@ -27,11 +27,11 @@ def problem():
 
 def test_EP_results(problem):
     models = [
-        EP.BaseEP(problem, epoch=10, pop_size=50, bout_size=0.2),
-        EP.LevyEP(problem, epoch=20, pop_size=50, bout_size=0.2),
+        EP.OriginalEP(epoch=10, pop_size=50, bout_size=0.2),
+        EP.LevyEP(epoch=20, pop_size=50, bout_size=0.2),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
