@@ -27,11 +27,11 @@ def problem():
 
 def test_ES_results(problem):
     models = [
-        ES.BaseES(problem, epoch=10, pop_size=50, lamda=0.7),
-        ES.LevyES(problem, epoch=20, pop_size=50, lamda=0.7),
+        ES.OriginalES(epoch=10, pop_size=50, lamda=0.7),
+        ES.LevyES(epoch=20, pop_size=50, lamda=0.7),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
