@@ -26,10 +26,10 @@ def problem():
 
 def test_FPA_results(problem):
     models = [
-        FPA.BaseFPA(problem, epoch=10, pop_size=50, p_s=0.8, levy_multiplier=0.2),
+        FPA.OriginalFPA(epoch=10, pop_size=50, p_s=0.8, levy_multiplier=0.2),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
