@@ -26,10 +26,10 @@ def problem():
 
 def test_GA_results(problem):
     models = [
-        GA.BaseGA(problem, epoch=10, pop_size=50, pc=0.9, pm=0.01),
+        GA.BaseGA(epoch=10, pop_size=50, pc=0.9, pm=0.01),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
