@@ -26,10 +26,10 @@ def problem():
 
 def test_MA_results(problem):
     models = [
-        MA.BaseMA(problem, epoch=10, pop_size=50, pc=0.85, pm=0.15, p_local=0.5, max_local_gens=20, bits_per_param=4),
+        MA.OriginalMA(epoch=10, pop_size=50, pc=0.85, pm=0.15, p_local=0.5, max_local_gens=20, bits_per_param=4),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
