@@ -26,11 +26,11 @@ def problem():
 
 def test_BRO_results(problem):
     models = [
-        BRO.OriginalBRO(problem, epoch=100, pop_size=50, threshold=1),
-        BRO.BaseBRO(problem, epoch=10, pop_size=50, threshold=1),
+        BRO.OriginalBRO(epoch=100, pop_size=50, threshold=1),
+        BRO.BaseBRO(epoch=10, pop_size=50, threshold=1),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
