@@ -26,10 +26,10 @@ def problem():
 
 def test_CA_results(problem):
     models = [
-        CA.OriginalCA(problem, epoch=10, pop_size=50, accepted_rate=0.15)
+        CA.OriginalCA(epoch=10, pop_size=50, accepted_rate=0.15)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
\ No newline at end of file
