@@ -27,11 +27,11 @@ def problem():
 
 def test_CHIO_results(problem):
     models = [
-        CHIO.OriginalCHIO(problem, epoch=10, pop_size=50, brr=0.15, max_age=2),
-        CHIO.BaseCHIO(problem, epoch=10, pop_size=50, brr=0.15, max_age=1)
+        CHIO.OriginalCHIO(epoch=10, pop_size=50, brr=0.15, max_age=2),
+        CHIO.BaseCHIO(epoch=10, pop_size=50, brr=0.15, max_age=1)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
