@@ -27,11 +27,11 @@ def problem():
 
 def test_FBIO_results(problem):
     models = [
-        FBIO.OriginalFBIO(problem, epoch=10, pop_size=50),
-        FBIO.BaseFBIO(problem, epoch=10, pop_size=50)
+        FBIO.OriginalFBIO(epoch=10, pop_size=50),
+        FBIO.BaseFBIO(epoch=10, pop_size=50)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
