@@ -27,11 +27,11 @@ def problem():
 
 def test_GSKA_results(problem):
     models = [
-        GSKA.OriginalGSKA(problem, epoch=10, pop_size=50, pb=0.1, kf=0.5, kr=0.9, kg=2),
-        GSKA.BaseGSKA(problem, epoch=10, pop_size=50, pb=0.1, kr=0.7)
+        GSKA.OriginalGSKA(epoch=10, pop_size=50, pb=0.1, kf=0.5, kr=0.9, kg=2),
+        GSKA.BaseGSKA(epoch=10, pop_size=50, pb=0.1, kr=0.7)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
