@@ -27,13 +27,13 @@ def problem():
 
 def test_LCO_results(problem):
     models = [
-        LCO.OriginalLCO(problem, epoch=10, pop_size=50, r1=2.35),
-        LCO.BaseLCO(problem, epoch=10, pop_size=50, r1=2.35),
-        LCO.ImprovedLCO(problem, epoch=10, pop_size=50)
+        LCO.OriginalLCO(epoch=10, pop_size=50, r1=2.35),
+        LCO.BaseLCO(epoch=10, pop_size=50, r1=2.35),
+        LCO.ImprovedLCO(epoch=10, pop_size=50)
     ]
 
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
