@@ -27,15 +27,15 @@ def problem():
 
 def test_QSA_results(problem):
     models = [
-        QSA.BaseQSA(problem, epoch=10, pop_size=50),
-        QSA.OriginalQSA(problem, epoch=10, pop_size=50),
-        QSA.OppoQSA(problem, epoch=10, pop_size=50),
-        QSA.LevyQSA(problem, epoch=10, pop_size=50),
-        QSA.ImprovedQSA(problem, epoch=10, pop_size=50)
+        QSA.BaseQSA(epoch=10, pop_size=50),
+        QSA.OriginalQSA(epoch=10, pop_size=50),
+        QSA.OppoQSA(epoch=10, pop_size=50),
+        QSA.LevyQSA(epoch=10, pop_size=50),
+        QSA.ImprovedQSA(epoch=10, pop_size=50)
     ]
 
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
