@@ -27,12 +27,12 @@ def problem():
 
 def test_SARO_results(problem):
     models = [
-        SARO.BaseSARO(problem, epoch=10, pop_size=50, se=0.5, mu=5),
-        SARO.OriginalSARO(problem, epoch=10, pop_size=50, se=0.5, mu=25),
+        SARO.BaseSARO(epoch=10, pop_size=50, se=0.5, mu=5),
+        SARO.OriginalSARO(epoch=10, pop_size=50, se=0.5, mu=25),
     ]
 
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
