@@ -27,12 +27,12 @@ def problem():
 
 def test_SSDO_results(problem):
     models = [
-        SSDO.BaseSSDO(problem, epoch=10, pop_size=50),
+        SSDO.OriginalSSDO(epoch=10, pop_size=50),
 
     ]
 
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
