@@ -27,13 +27,13 @@ def problem():
 
 def test_TLO_results(problem):
     models = [
-        TLO.BaseTLO(problem, epoch=10, pop_size=50),
-        TLO.OriginalTLO(problem, epoch=10, pop_size=50),
-        TLO.ITLO(problem, epoch=10, pop_size=50, n_teachers=5),
+        TLO.BaseTLO(epoch=10, pop_size=50),
+        TLO.OriginalTLO(epoch=10, pop_size=50),
+        TLO.ImprovedTLO(epoch=10, pop_size=50, n_teachers=5),
     ]
 
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
