@@ -26,10 +26,10 @@ def problem():
 
 def test_CGO_results(problem):
     models = [
-        CGO.OriginalCGO(problem, epoch=100, pop_size=50),
+        CGO.OriginalCGO(epoch=100, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
