@@ -27,10 +27,10 @@ def problem():
 
 def test_PSS_results(problem):
     models = [
-        PSS.OriginalPSS(problem, epoch=100, pop_size=50, acceptance_rate=0.9, sampling_method="LHS")
+        PSS.OriginalPSS(epoch=100, pop_size=50, acceptance_rate=0.9, sampling_method="LHS")
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
