@@ -26,11 +26,11 @@ def problem():
 
 def test_SCA_results(problem):
     models = [
-        SCA.OriginalSCA(problem, epoch=100, pop_size=50),
-        SCA.BaseSCA(problem, epoch=100, pop_size=50),
+        SCA.OriginalSCA(epoch=100, pop_size=50),
+        SCA.BaseSCA(epoch=100, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
