@@ -27,11 +27,11 @@ def problem():
 
 def test_HS_results(problem):
     models = [
-        HS.OriginalHS(problem, epoch=100, pop_size=50),
-        HS.BaseHS(problem, epoch=100, pop_size=50),
+        HS.OriginalHS(epoch=100, pop_size=50),
+        HS.BaseHS(epoch=100, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
