@@ -26,10 +26,10 @@ def problem():
 
 def test_ASO_results(problem):
     models = [
-        ASO.BaseASO(problem, epoch=100, pop_size=50, alpha=50, beta=0.2),
+        ASO.OriginalASO(epoch=100, pop_size=50, alpha=50, beta=0.2),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
