@@ -27,12 +27,12 @@ def problem():
 
 def test_EO_results(problem):
     models = [
-        EO.BaseEO(problem, epoch=100, pop_size=50),
-        EO.ModifiedEO(problem, epoch=100, pop_size=50),
-        EO.AdaptiveEO(problem, epoch=100, pop_size=50),
+        EO.OriginalEO(epoch=100, pop_size=50),
+        EO.ModifiedEO(epoch=100, pop_size=50),
+        EO.AdaptiveEO(epoch=100, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
