@@ -27,10 +27,10 @@ def problem():
 
 def test_HGSO_results(problem):
     models = [
-        HGSO.BaseHGSO(problem, epoch=100, pop_size=50, n_clusters=3),
+        HGSO.OriginalHGSO(epoch=100, pop_size=50, n_clusters=3),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
