@@ -27,11 +27,11 @@ def problem():
 
 def test_MVO_results(problem):
     models = [
-        MVO.BaseMVO(problem, epoch=100, pop_size=50, wep_min=0.2, wep_max=1.0),
-        MVO.OriginalMVO(problem, epoch=100, pop_size=50, wep_min=0.2, wep_max=1.0),
+        MVO.BaseMVO(epoch=100, pop_size=50, wep_min=0.2, wep_max=1.0),
+        MVO.OriginalMVO(epoch=100, pop_size=50, wep_min=0.2, wep_max=1.0),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
