@@ -27,13 +27,13 @@ def problem():
 
 def test_TWO_results(problem):
     models = [
-        TWO.BaseTWO(problem, epoch=100, pop_size=50),
-        TWO.OppoTWO(problem, epoch=100, pop_size=50),
-        TWO.LevyTWO(problem, epoch=100, pop_size=50),
-        TWO.EnhancedTWO(problem, epoch=100, pop_size=50),
+        TWO.OriginalTWO(epoch=100, pop_size=50),
+        TWO.OppoTWO(epoch=100, pop_size=50),
+        TWO.LevyTWO(epoch=100, pop_size=50),
+        TWO.EnhancedTWO(epoch=100, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
