@@ -27,10 +27,10 @@ def problem():
 
 def test_ACOR_results(problem):
     models = [
-        ACOR.BaseACOR(problem, epoch=10, pop_size=50, sample_count=25, intent_factor=0.5, zeta=1.0)
+        ACOR.OriginalACOR(epoch=10, pop_size=50, sample_count=25, intent_factor=0.5, zeta=1.0)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
