@@ -27,10 +27,10 @@ def problem():
 
 def test_ALO_results(problem):
     models = [
-        ALO.BaseALO(problem, epoch=10, pop_size=50)
+        ALO.BaseALO(epoch=10, pop_size=50)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
