@@ -27,10 +27,10 @@ def problem():
 
 def test_COA_results(problem):
     models = [
-        COA.BaseCOA(problem, epoch=10, pop_size=50, n_coyotes=5)
+        COA.OriginalCOA(epoch=10, pop_size=50, n_coyotes=5)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
