@@ -27,10 +27,10 @@ def problem():
 
 def test_CSA_results(problem):
     models = [
-        CSA.BaseCSA(problem, epoch=10, pop_size=50, p_a=0.3)
+        CSA.OriginalCSA(epoch=10, pop_size=50, p_a=0.3)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
