@@ -27,10 +27,10 @@ def problem():
 
 def test_EHO_results(problem):
     models = [
-        EHO.BaseEHO(problem, epoch=10, pop_size=50, alpha=0.5, beta=0.5, n_clans=5)
+        EHO.OriginalEHO(epoch=10, pop_size=50, alpha=0.5, beta=0.5, n_clans=5)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
