@@ -27,10 +27,10 @@ def problem():
 
 def test_FA_results(problem):
     models = [
-        FA.BaseFA(problem, epoch=10, pop_size=50, max_sparks=20, p_a=0.04, p_b=0.8, max_ea=40, m_sparks=5)
+        FA.OriginalFA(epoch=10, pop_size=50, max_sparks=20, p_a=0.04, p_b=0.8, max_ea=40, m_sparks=5)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
