@@ -27,10 +27,10 @@ def problem():
 
 def test_GOA_results(problem):
     models = [
-        GOA.BaseGOA(problem, epoch=10, pop_size=50),
+        GOA.OriginalGOA(epoch=10, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
