@@ -27,11 +27,11 @@ def problem():
 
 def test_GWO_results(problem):
     models = [
-        GWO.BaseGWO(problem, epoch=10, pop_size=50),
-        GWO.RW_GWO(problem, epoch=10, pop_size=50),
+        GWO.OriginalGWO(epoch=10, pop_size=50),
+        GWO.RW_GWO(epoch=10, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
