@@ -27,10 +27,10 @@ def problem():
 
 def test_HGS_results(problem):
     models = [
-        HGS.OriginalHGS(problem, epoch=10, pop_size=50, PUP=0.08, LH=10000),
+        HGS.OriginalHGS(epoch=10, pop_size=50, PUP=0.08, LH=10000),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
