@@ -27,12 +27,12 @@ def problem():
 
 def test_JA_results(problem):
     models = [
-        JA.BaseJA(problem, epoch=10, pop_size=50),
-        JA.OriginalJA(problem, epoch=10, pop_size=50),
-        JA.LevyJA(problem, epoch=10, pop_size=50),
+        JA.BaseJA(epoch=10, pop_size=50),
+        JA.OriginalJA(epoch=10, pop_size=50),
+        JA.LevyJA(epoch=10, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
