@@ -27,11 +27,11 @@ def problem():
 
 def test_MFO_results(problem):
     models = [
-        MFO.BaseMFO(problem, epoch=10, pop_size=50),
-        MFO.OriginalMFO(problem, epoch=10, pop_size=50),
+        MFO.BaseMFO(epoch=10, pop_size=50),
+        MFO.OriginalMFO(epoch=10, pop_size=50),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
