@@ -27,10 +27,10 @@ def problem():
 
 def test_MSA_results(problem):
     models = [
-        MSA.BaseMSA(problem, epoch=10, pop_size=50, n_best=5, partition=0.5, max_step_size=1.0),
+        MSA.OriginalMSA(epoch=10, pop_size=50, n_best=5, partition=0.5, max_step_size=1.0),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
