@@ -27,11 +27,11 @@ def problem():
 
 def test_NMRA_results(problem):
     models = [
-        NMRA.BaseNMRA(problem, epoch=10, pop_size=50, pb=0.75),
-        NMRA.ImprovedNMRA(problem, epoch=10, pop_size=50, pb=0.75, pm=0.01),
+        NMRA.OriginalNMRA(epoch=10, pop_size=50, pb=0.75),
+        NMRA.ImprovedNMRA(epoch=10, pop_size=50, pb=0.75, pm=0.01),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
