@@ -27,11 +27,11 @@ def problem():
 
 def test_SFO_results(problem):
     models = [
-        SFO.BaseSFO(problem, epoch=10, pop_size=50, pp=0.1, AP=4, epxilon=0.0001),
-        SFO.ImprovedSFO(problem, epoch=10, pop_size=50, pp=0.1)
+        SFO.OriginalSFO(epoch=10, pop_size=50, pp=0.1, AP=4, epxilon=0.0001),
+        SFO.ImprovedSFO(epoch=10, pop_size=50, pp=0.1)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
