@@ -29,12 +29,12 @@ def problem():
 
 def test_SLO_results(problem):
     models = [
-        SLO.BaseSLO(problem, epoch=10, pop_size=50),
-        SLO.ModifiedSLO(problem, epoch=10, pop_size=50),
-        SLO.ISLO(problem, epoch=10, pop_size=50, c1=1.2, c2=1.2)
+        SLO.OriginalSLO(epoch=10, pop_size=50),
+        SLO.ModifiedSLO(epoch=10, pop_size=50),
+        SLO.ImprovedSLO(epoch=10, pop_size=50, c1=1.2, c2=1.2)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
