@@ -27,11 +27,11 @@ def problem():
 
 def test_SSA_results(problem):
     models = [
-        SSA.OriginalSSA(problem, epoch=10, pop_size=50, ST=0.8, PD=0.2, SD=0.1),
-        SSA.BaseSSA(problem, epoch=10, pop_size=50, ST=0.8, PD=0.2, SD=0.1)
+        SSA.OriginalSSA(epoch=10, pop_size=50, ST=0.8, PD=0.2, SD=0.1),
+        SSA.BaseSSA(epoch=10, pop_size=50, ST=0.8, PD=0.2, SD=0.1)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
