@@ -27,10 +27,10 @@ def problem():
 
 def test_SSpiderA_results(problem):
     models = [
-        SSpiderA.BaseSSpiderA(problem, epoch=10, pop_size=50, r_a=1, p_c=0.7, p_m=0.1)
+        SSpiderA.OriginalSSpiderA(epoch=10, pop_size=50, r_a=1, p_c=0.7, p_m=0.1)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
