@@ -27,10 +27,10 @@ def problem():
 
 def test_SSpiderO_results(problem):
     models = [
-        SSpiderO.BaseSSpiderO(problem, epoch=10, pop_size=50, fp=(0.65, 0.9))
+        SSpiderO.OriginalSSpiderO(epoch=10, pop_size=50, fp=(0.65, 0.9))
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
