@@ -27,11 +27,11 @@ def problem():
 
 def test_WOA_results(problem):
     models = [
-        WOA.BaseWOA(problem, epoch=10, pop_size=50),
-        WOA.HI_WOA(problem, epoch=10, pop_size=50, feedback_max=5)
+        WOA.OriginalWOA(epoch=10, pop_size=50),
+        WOA.HI_WOA(epoch=10, pop_size=50, feedback_max=5)
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
