@@ -27,11 +27,11 @@ def problem():
 
 def test_GCO_results(problem):
     models = [
-        GCO.OriginalGCO(problem, epoch=10, pop_size=50, cr=0.7, wf=1.25),
-        GCO.BaseGCO(problem, epoch=10, pop_size=50, cr=0.7, wf=1.25),
+        GCO.OriginalGCO(epoch=10, pop_size=50, cr=0.7, wf=1.25),
+        GCO.BaseGCO(epoch=10, pop_size=50, cr=0.7, wf=1.25),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
