@@ -27,10 +27,10 @@ def problem():
 
 def test_WCA_results(problem):
     models = [
-        WCA.BaseWCA(problem, epoch=10, pop_size=50, cr=0.7, wf=1.25),
+        WCA.OriginalWCA(epoch=10, pop_size=50, cr=0.7, wf=1.25),
     ]
     for model in models:
-        best_position, best_fitness = model.solve()
+        best_position, best_fitness = model.solve(problem)
         assert isinstance(model, Optimizer)
         assert isinstance(best_position, np.ndarray)
         assert len(best_position) == len(problem["lb"])
